<?php

/*
 *
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
*/
if (!class_exists('NHP_Options')) {
    require_once( dirname(__FILE__) . '/options/options.php' );
}

/*
 *
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
*/

function add_another_section($sections) {

    //$sections = array();
    $sections[] = array(
            'title' => __('A Section added by hook', 'nhp-opts'),
            'desc' => __('<p class="description">This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.</p>', 'nhp-opts'),
            //all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
            //You dont have to though, leave it blank for default.
            'icon' => get_template_directory_uri() . 'options/img/glyphicons/glyphicons_062_attach.png',
            //Lets leave this as a blank section, no options just some intro text set above.
            'fields' => array()
    );

    return $sections;
}

//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 *
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
*/

function change_framework_args($args) {

    //$args['dev_mode'] = false;

    return $args;
}

//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');









/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
*/

function setup_framework_options() {
    $args = array();

//Set it to dev mode to view the class settings/info in the form - default is false
    $args['dev_mode'] = false;

//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
//$args['stylesheet_override'] = true;
//Add HTML before the form
    $args['intro_text'] = __('<p>Welcome to Options Panel. If something is not clear, please reffer to documentation.</p>', 'nhp-opts');

//Setup custom links in the footer for share icons
//$args['share_icons']['twitter'] = array(
//										'link' => 'http://twitter.com/lee__mason',
//										'title' => 'Folow me on Twitter',
//										'img' => NHP_OPTIONS_URL.'img/glyphicons/glyphicons_322_twitter.png'
//										);
//$args['share_icons']['linked_in'] = array(
//										'link' => 'http://uk.linkedin.com/pub/lee-mason/38/618/bab',
//										'title' => 'Find me on LinkedIn',
//										'img' => NHP_OPTIONS_URL.'img/glyphicons/glyphicons_337_linked_in.png'
//										);
//Choose to disable the import/export feature
//$args['show_import_export'] = false;
//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
    $args['opt_name'] = 'magnovus';

//Custom menu icon
//$args['menu_icon'] = '';
//Custom menu title for options page - default is "Options"
    $args['menu_title'] = __('Magnovus Options', 'nhp-opts');

//Custom Page Title for options page - default is "Options"
    $args['page_title'] = __('Magnovus Theme Options', 'nhp-opts');

//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
    $args['page_slug'] = 'theme_options';

//Custom page capability - default is set to "manage_options"
//$args['page_cap'] = 'manage_options';
//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
    $args['page_type'] = 'submenu';

//parent menu - default is set to "themes.php" (Appearance)
//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
//$args['page_parent'] = 'themes.php';
//custom page location - default 100 - must be unique or will override other items
//$args['page_position'] = 10;
//Custom page icon class (used to override the page icon next to heading)
//$args['page_icon'] = 'icon-themes';
//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition
//    $args['help_tabs'][] = array(
//            'id' => 'nhp-opts-1',
//            'title' => __('Theme Information 1', 'nhp-opts'),
//            'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'nhp-opts')
//    );
//    $args['help_tabs'][] = array(
//            'id' => 'nhp-opts-2',
//            'title' => __('Theme Information 2', 'nhp-opts'),
//            'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'nhp-opts')
//    );
//
////Set the Help Sidebar for the options page - no sidebar by default
//    $args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'nhp-opts');



    $sections = array();



    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_280_settings.png',
            'title' => __('General Options', 'nhp-opts'),
            'desc' => __('<p class="description">You\'ll find here general options to setup theme.</p>', 'nhp-opts'),
            'fields' => array(
                    array(
                            'id' => 'top_menu',
                            'type' => 'select',
                            'title' => __('Top Menu', 'nhp-opts'),
                            //'sub_desc' => __('No validation can be done on this field type', 'nhp-opts'),
                            'desc' => __('Show/hide top bar', 'nhp-opts'),
                            'options' => array('1' => 'Show', '2' => 'Hide'), //Must provide key => value pairs for select options
                            'std' => '1'
                    ),
                    array(
                            'id' => 'top_social',
                            'type' => 'multi_checkbox',
                            'title' => __('Social icons in Top Menu', 'nhp-opts'),
                            'sub_desc' => __('Choose which elements to show', 'nhp-opts'),
                            'options' => array(
                                    'rss' => 'RSS',
                                    'fb' => 'Facebook',
                                    'twitter' => 'Twitter',
                                    'google' => 'Google Plus',
                                    'youtube' => 'Youtube',
                                    'linkedin' => 'LinkedIn',
                                    'flickr' => 'Flickr',
                                    'digg' => 'Digg'

                            ), //Must provide key => value pairs for multi checkbox options
                            'std' => array('rss' => '1', 'fb' => '1', 'twitter' => '1')//See how std has changed? you also dont need to specify opts that are 0.
                    ),
                    array(
                            'id' => 'top_social_url',
                            'type' => 'multi_texts',
                            'title' => __('Social icons in Top Menu', 'nhp-opts'),
                            'sub_desc' => __('Choose which elements to show', 'nhp-opts'),
                            'options' => array(
                                    'fb' => 'Facebook profile url',
                                    'twitter' => 'Twitter profile url',
                                    'google' => 'Google Plus profile url',
                                    'youtube' => 'Youtube profile url',
                                    'linkedin' => 'LinkedIn profile url',
                                    'flickr' => 'Flickr profile url',
                                    'digg' => 'Digg profile url'

                            ), //Must provide key => value pairs for multi checkbox options
                            'std' => array('rss' => '1', 'fb' => '1', 'twitter' => '1')//See how std has changed? you also dont need to specify opts that are 0.
                    ),
                    array(
                            'id' => 'top_search',
                            'type' => 'select',
                            'title' => __('Top Search', 'nhp-opts'),
                            //'sub_desc' => __('No validation can be done on this field type', 'nhp-opts'),
                            'desc' => __('Show/hide top search input', 'nhp-opts'),
                            'options' => array('1' => 'Show', '2' => 'Hide'), //Must provide key => value pairs for select options
                            'std' => '1'
                    ),
                       array(
                            'id' => 'menuicons',
                            'type' => 'select',
                            'title' => __('User register/login icons in menu', 'nhp-opts'),
                            'options' => array(
                                    'show' => 'Show',
                                    'hide' => 'Hide',
                            ),
                            'std' => 'hide'
                    ),
                    array(
                            'id' => 'logo',
                            'type' => 'upload',
                            'title' => __('Upload Logo', 'nhp-opts'),
                            'sub_desc' => __('Blog name will be used if no logo is present', 'nhp-opts'),
                    ),

                    array(
                            'id' => 'logomargintop',
                            'type' => 'text',
                            'title' => __('Logo top margin', 'nhp-opts'),
                            'desc' => __('If you want to create more whitespace above logo ', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'logomarginbottom',
                            'type' => 'text',
                            'title' => __('Logo bottom margin', 'nhp-opts'),
                            'desc' => __('If you want to create more whitespace under logo ', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'sidebarside',
                            'type' => 'select',
                            'title' => __('Select Right or Left Sidebar', 'nhp-opts'),
                            'options' => array(
                                    'left' => 'Left',
                                    'right' => 'Right',
                            ),
                            'std' => 'right'
                    ),
                    array(
                            'id' => 'author_role',
                            'type' => 'select',
                            'title' => __('Select which users should be displayed on Authors list template page', 'nhp-opts'),
                            'sub_desc' => __('More info in documentation', 'nhp-opts'),
                            'options' => array(
                                    'author' => 'Author',
                                    'subscriber' => 'Subscriber',
                                    'editor' => 'Editor',
                                    'contributor' => 'Contributor',
                                    'administrator' => 'Administrator'
                            ), //Must provide key => value pairs for multi checkbox options
                            'std' => 'author'
                    ),

                    array(
                            'id' => 'footertext',
                            'type' => 'text',
                            'title' => __('Copyrights footer text', 'nhp-opts'),
                            'std' => '&copy; 2012 <strong>MAGNOVUS</strong> '
                    ),
            )
    );
   $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_318_more-items.png',
            'title' => __('Posts/pages Settings', 'nhp-opts'),
            'desc' => __('<p class="description">Edit colors settings and backgrounds.</p>', 'nhp-opts'),
            'fields' => array(
                     array(
                            'id' => 'authorinfo',
                            'type' => 'multi_checkbox',
                            'title' => __('Show author infobox under', 'nhp-opts'),
                            'sub_desc' => __('Remember that to display infobox author must have some content in Bio field in his profile', 'nhp-opts'),
                            'options' => array(
                                    'post' => 'Post',
                                    'page' => 'Page'

                            ), //Must provide key => value pairs for multi checkbox options
                            'std' => array('post' => '1', 'page' => '1')//See how std has changed? you also dont need to specify opts that are 0.
                    ),
                    array(
                            'id' => 'postshares',
                            'type' => 'multi_checkbox',
                            'title' => __('Show share buttons under each', 'nhp-opts'),
                            'options' => array(
                                    'post' => 'Post',
                                    'page' => 'Page'

                            ), //Must provide key => value pairs for multi checkbox options
                            'std' => array('post' => '1', 'page' => '1')//See how std has changed? you also dont need to specify opts that are 0.
                    ),
               )
                );
    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_092_tint.png',
            'title' => __('Color Settings', 'nhp-opts'),
            'desc' => __('<p class="description">Edit colors settings and backgrounds.</p>', 'nhp-opts'),
            'fields' => array(
                    array(
                            'id' => 'style',
                            'type' => 'select',
                            'title' => __('General style', 'nhp-opts'),
                            'options' => array(
                                    'solid' => 'Solid with white background',
                                    'custom' => 'Custom background color',
                                    'fullbg' => 'Full-screen background image',
                                    'patternbg' => 'Pattern background image',

                            ),
                            'std' => 'no'
                    ),
                    array(
                            'id' => 'bgcolor',
                            'type' => 'color',
                            'desc' => __('Active only when "General style: Custom background color" is selected', 'nhp-opts'),
                            'title' => __('Solid background color', 'nhp-opts'),
                            'std' => '#fff'// 1 = on | 0 = off
                    ),


                    array(
                            'id' => 'bgimg',
                            'type' => 'upload',
                            'title' => __('Upload background image', 'nhp-opts'),
                            'sub_desc' => __('Anything from full-size photo to small pattern', 'nhp-opts'),
                    ),

                    array(
                            'id' => 'bgrepeat',
                            'type' => 'select',
                            'title' => __('Background repeat', 'nhp-opts'),
                            'options' => array(
                                    'repeat' => 'repeat',
                                    'no-repeat' => 'no-repeat',
                                    'repeat-x' => 'repeat-x',
                                    'repeat-y' => 'repeat-y'

                            ),
                            'std' => 'repeat'
                    ),
                    array(
                            'id' => 'bgpos',
                            'type' => 'select',
                            'title' => __('Background position', 'nhp-opts'),
                            'options' => array(
                                    'top left' => 'top left',
                                    'top center' => 'top center',
                                    'top right' => 'top right',
                                    'center center' => 'center center',
                                    'bottom left' => 'bottom left',
                                    'bottom center' => 'bottom center',
                                    'bottom right' => 'bottom right'

                            ),
                            'std' => 'top left'
                    ),

                    array(
                            'id' => 'customcolors',
                            'type' => 'select',
                            'title' => __('Enable custom colors', 'nhp-opts'),
                            'options' => array(
                                    'no' => 'No',
                                    'yes' => 'Yes',

                            ),
                            'std' => 'no'
                    ),
                    array(
                            'id' => 'color1',
                            'type' => 'color',
                            'title' => __('Colour 1 (default blue #2DB3E9)', 'nhp-opts'),
                            'std' => '#2DB3E9'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'color2',
                            'type' => 'color',
                            'title' => __('Colour 2 (default green #70B427)', 'nhp-opts'),
                            'std' => '#70B427'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'color3',
                            'type' => 'color',
                            'title' => __('Colour 3 (default orange #FF7200)', 'nhp-opts'),
                            'std' => '#FF7200'// 1 = on | 0 = off
                    ),

            ));
    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_227_usd.png',
            'title' => __('Ads Settings', 'nhp-opts'),

            'fields' => array(
                    array(
                            'id' => 'adinfo',
                            'type' => 'info',
                            'desc' => __('<p >You can here just switch on/off top area for ads in theme. It\'s widgetized sidebar - you can put your add using "Text" widget or plugin which supports
                             widgets - Go to Appearance - Widgets - and drag it to "Top ad area".</p>', 'nhp-opts')
                    ),
                    array(
                            'id' => 'topadstatus',
                            'type' => 'checkbox',
                            'title' => __('Show ad in top', 'nhp-opts'),
                            'desc' => __('Check to enable ads area next to logo.', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
            ));

    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_020_home.png',
            'title' => __('Home page columns', 'nhp-opts'),
            'desc' => __('<p class="description">Set columns content on home page.</p>', 'nhp-opts'),
            'fields' => array(
                    array(
                            'id' => 'columns12',
                            'type' => 'checkbox',
                            'title' => __('Show 1st & 2nd column', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'posts12number',
                            'type' => 'text',
                            'validate' => 'numeric',
                            'title' => __('How many posts should columns 1 & 2 display?', 'nhp-opts'),
                            'std' => '4'
                    ),
                    array(
                            'id' => 'first_column_title',
                            'type' => 'text',
                            'title' => __('Title for 1st column', 'nhp-opts')
                    ),
                    array(
                            'id' => 'first_columns_cats',
                            'type' => 'cats_multi_select',
                            'title' => __('Choose categories for 1st column', 'nhp-opts'),
                            'args' => array('number' => '0')//uses get_categories
                    ),
                    array(
                            'id' => 'second_column_title',
                            'type' => 'text',
                            'title' => __('Title for 2nd column', 'nhp-opts')
                    ),
                    array(
                            'id' => 'second_columns_cats',
                            'type' => 'cats_multi_select',
                            'title' => __('Choose categories for 2nd column', 'nhp-opts'),
                            'args' => array('number' => '0')//uses get_categories
                    ),
                    array(
                            'id' => 'divide',
                            'type' => 'divide',
                    ),
                    array(
                            'id' => 'columns34',
                            'type' => 'checkbox',
                            'title' => __('Show 3rd & 4th column', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'posts34number',
                            'type' => 'text',
                            'validate' => 'numeric',
                            'title' => __('How many posts should columns 3 & 4 display?', 'nhp-opts'),
                            'std' => '4'
                    ),
                    array(
                            'id' => 'third_column_title',
                            'type' => 'text',
                            'title' => __('Title for 3rd column', 'nhp-opts')
                    ),
                    array(
                            'id' => 'third_columns_cats',
                            'type' => 'cats_multi_select',
                            'title' => __('Choose categories for 3rd column', 'nhp-opts'),
                            'args' => array('number' => '0')//uses get_categories
                    ),
                    array(
                            'id' => 'fourth_column_title',
                            'type' => 'text',
                            'title' => __('Title for 4th column', 'nhp-opts')
                    ),
                    array(
                            'id' => 'fourth_columns_cats',
                            'type' => 'cats_multi_select',
                            'title' => __('Choose categories for 4th column', 'nhp-opts'),
                            'args' => array('number' => '0')//uses get_categories
                    ),
            )
    );

    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_071_book.png',
            'title' => __('Sidebar settings', 'nhp-opts'),
            'desc' => __('<p class="description">Settings for sidebar.</p>', 'nhp-opts'),
            'fields' => array(
                    array(
                            'id' => 'countwidget',
                            'type' => 'checkbox',
                            'title' => __('Show counter widget', 'nhp-opts'),
                            'desc' => __('Check to show counter widget.', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'twittercount',
                            'type' => 'text',
                            'title' => __('Show twitter followers counter', 'nhp-opts'),
                            'desc' => __('Put your twitter username, leave empty to disable', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'facebookcount',
                            'type' => 'text',
                            'title' => __('Show facebook followers counter', 'nhp-opts'),
                            'desc' => __('Put facebook page ID, leave empty to disable', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'facebookurl',
                            'type' => 'text',
                            'title' => __('Facebook page url', 'nhp-opts'),
                            'desc' => __('Put facebook page url', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'rsscount',
                            'type' => 'text',
                            'title' => __('Show rss counter', 'nhp-opts'),
                            'desc' => __('Put your feedburner name here, leave empty to disable', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'rssmanualcount',
                            'type' => 'text',
                            'title' => __('RSS followers number', 'nhp-opts'),
                            'desc' => __('If for some reason function to display current number of followers doesn\'t work, you can put it here manually', 'nhp-opts'),
                    ),
                    array(
                            'id' => 'commentscount',
                            'type' => 'checkbox',
                            'title' => __('Show comments counter ', 'nhp-opts'),
                            'desc' => __('Check to show comment counter.', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
            )
    );
    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_009_magic.png',
            'title' => __('AJAX settings', 'nhp-opts'),
            'desc' => __('<p class="description">You\'ll find here general options to setup theme.</p>', 'nhp-opts'),
            'fields' => array(
                    array(
                            'id' => 'ajaxstatus',
                            'type' => 'checkbox',
                            'title' => __('Enable Ajax posts sorting', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'ajaxpagination',
                            'type' => 'checkbox',
                            'title' => __('Enable Ajax pagination', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
            )
    );
    $sections[] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_056_projector.png',
            'title' => __('Slider settings', 'nhp-opts'),
            'desc' => __('<p class="description">You\'ll find here general options to setup theme.</p>', 'nhp-opts'),
            'fields' => array(
                    array(
                            'id' => 'sliderstatus',
                            'type' => 'checkbox',
                            'title' => __('Enable Slider', 'nhp-opts'),
                            'std' => '0'// 1 = on | 0 = off
                    ),
                    array(
                            'id' => 'slider_content',
                            'type' => 'select',
                            'title' => __('Select Content', 'nhp-opts'),
                            'sub_desc' => __('Select what should appear as slider content ', 'nhp-opts'),
                            'options' => array(
                                    'cats' => 'Categories',
                                    'posts' => 'Posts'
                            ),
                            'std' => 'random'
                    ),
                    array(
                            'id' => 'divide',
                            'type' => 'divide',
                    ),
                    array(
                            'id' => 'cats_for_slider',
                            'type' => 'cats_multi_select',
                            'title' => __('Choose categories for slider', 'nhp-opts'),
                            'args' => array('number' => '99')//uses get_categories
                    ),
                    array(
                            'id' => 'slidesnumber',
                            'type' => 'text',
                            'validate' => 'numeric',
                            'title' => __('How many slides should it take from choosen categories', 'nhp-opts'),
                            'std' => '10'
                    ),

                    array(
                            'id' => 'posts_for_slider',
                            'type' => 'posts_multi_select',
                            'title' => __('Choose posts for slider', 'nhp-opts'),
                            'sub_desc' => __('You need to select posts for content', 'nhp-opts'),
                            'args' => array('numberposts' => '99')//uses get_posts
                    ),


                    array(
                            'id' => 'divide',
                            'type' => 'divide',
                    ),
                    array(
                            'id' => 'slider_effect',
                            'type' => 'select',
                            'title' => __('Select Slider Effect', 'nhp-opts'),
                            'sub_desc' => __('No validation can be done on this field type', 'nhp-opts'),
                            'desc' => __('This is the description field, again good for additional info.', 'nhp-opts'),
                            'options' => array(
                                    'fadeIn' => 'fadeIn',
                                    'fadeInUp' => 'fadeInUp',
                                    'fadeInDown' => 'fadeInDown',
                                    'fadeInLeft' => 'fadeInLeft',
                                    'fadeInRight' => 'fadeInRight',
                                    'fadeInRight' => 'fadeInRight',
                                    'bounceIn' => 'bounceIn',
                                    'bounceInDown' => 'bounceInDown',
                                    'bounceInUp' => 'bounceInUp',
                                    'bounceInLeft' => 'bounceInLeft',
                                    'bounceInRight' => 'bounceInRight',
                                    'rotateIn' => 'rotateIn',
                                    'rotateInDownLeft' => 'rotateInDownLeft',
                                    'rotateInDownRight' => 'rotateInDownRight',
                                    'rotateInUpLeft' => 'rotateInUpLeft',
                                    'rotateInUpRight' => 'rotateInUpRight',
                                    'random' => 'random'
                            ),
                            'std' => 'random'
                    ),
                    array(
                            'id' => 'slideshowdelay',
                            'type' => 'text',
                            'validate' => 'numeric',
                            'title' => __('Slide Show Delay', 'nhp-opts'),
                            'std' => '300'
                    ),
            )
    );






    $tabs = array();

    $theme_data = wp_get_theme();
    $theme_info = '<div class="nhp-opts-section-desc">';
    $theme_info .= '<p class="nhp-opts-theme-data description theme-uri">' . __('<strong>Theme URL:</strong> ', 'nhp-opts') . '<a href="' . $theme_data['URI'] . '" target="_blank">' . $theme_data['URI'] . '</a></p>';
    $theme_info .= '<p class="nhp-opts-theme-data description theme-author">' . __('<strong>Author:</strong> ', 'nhp-opts') . $theme_data['Author'] . '</p>';
    $theme_info .= '<p class="nhp-opts-theme-data description theme-version">' . __('<strong>Version:</strong> ', 'nhp-opts') . $theme_data['Version'] . '</p>';
    $theme_info .= '<p class="nhp-opts-theme-data description theme-description">' . $theme_data['Description'] . '</p>';
    $theme_info .= '<p class="nhp-opts-theme-data description theme-tags">' . __('<strong>Tags:</strong> ', 'nhp-opts') . implode(', ', $theme_data['Tags']) . '</p>';
    $theme_info .= '</div>';



    $tabs['theme_info'] = array(
            'icon' => NHP_OPTIONS_URL . 'img/glyphicons/glyphicons_195_circle_info.png',
            'title' => __('Theme Information', 'nhp-opts'),
            'content' => $theme_info
    );

//	$tabs['theme_docs'] = array(
//					'icon' => NHP_OPTIONS_URL.'img/glyphicons/glyphicons_071_book.png',
//					'title' => __('Documentation', 'nhp-opts'),
//					'content' => nl2br(file_get_contents(trailingslashit(get_stylesheet_directory()).'README.html'))
//					);

    global $NHP_Options;
    $NHP_Options = new NHP_Options($sections, $args, $tabs);
}

//function
add_action('init', 'setup_framework_options', 0);

/*
 *
 * Custom function for the callback referenced above
 *
*/

function my_custom_field($field, $value) {
    print_r($field);
    print_r($value);
}

//function

/*
 *
 * Custom function for the callback validation referenced above
 *
*/

function validate_callback_function($field, $value, $existing_value) {

    $error = false;
    $value = 'just testing';
    /*
      do your validation

      if(something){
      $value = $value;
      }elseif(somthing else){
      $error = true;
      $value = $existing_value;
      $field['msg'] = 'your custom error message';
      }
    */

    $return['value'] = $value;
    if ($error == true) {
        $return['error'] = $field;
    }
    return $return;
}

//function
?>